@@ -7,7 +7,8 @@ use Types::Standard -types;
 
 use namespace::autoclean;
 
-use version; our $VERSION = version->declare('v0.1.2');
+use version;
+$File::Rotate::Simple::VERSION = version->declare('v0.1.3');
 
 =head1 NAME
 
@@ -84,7 +85,7 @@ The file to rotate. This can be a string or L<Path::Tiny> object.
 
 =head2 C<files>
 
-When L</rotate> is called as a constructor, you can spefify an array
+When L</rotate> is called as a constructor, you can specify an array
 reference of files to rotate.
 
 =cut
@@ -129,7 +130,7 @@ sub _build_files {
 
         my $index = $1;
 
-        $files[ $index // 0 ] = $file;
+        $files[ $index || 0 ] = $file;
 
     }
 
@@ -201,7 +202,7 @@ sub rotate {
 
 =head1 AUTHOR
 
-Robert Rothenberg, C<< <rrwo at cpan.org> >>
+Robert Rothenberg, C<rrwo@cpan.org>
 
 =head1 LICENSE AND COPYRIGHT
 
